==> bot_2.1.tar.bz2: bot/class/DOMHelper.php <==
<?php
/************************************************** 
 *                 Bot Gadu-Gadu                  * 
 ************************************************** 
 * Wersja: 2.1                                    * 
 * Data: 13.02.2012 (19:41)                       * 
 * Autor: Jacek Kowalski (http://jacekk.info)     * 
 *                                                * 
 * Utwor rozprowadzany na licencji                * 
 * http://creativecommons.org/licenses/by-nc/2.5/ * 
 **************************************************/

class DOMHelper {
	static function ltrim($node) {
		while(($node->firstChild instanceof DOMElement) && $node->firstChild->tagName == 'br' && $node->lastChild->getAttribute('auto')=='1') {
			$node->removeChild($node->firstChild);
		}
		
		if($node->firstChild instanceof DOMElement) {
			self::ltrim($node->firstChid);
		}
	}
	
	static function rtrim($node) {
		while(($node->lastChild instanceof DOMElement) && $node->lastChild->tagName == 'br' && $node->lastChild->getAttribute('auto')=='1') {
			$node->removeChild($node->lastChild);
		}
		
		if($node->lastChild instanceof DOMElement) {
			self::rtrim($node->lastChild);
		}
	}
	
	static function trim($node) {
		self::ltrim($node);
		self::rtrim($node);
	}
	
	static function cloneNode($node, $saveto, $tag=NULL) {
		if($tag === NULL) {
			$tag = $node->tagName;
		}
		
		$saveto = $saveto->ownerDocument->createElement($tag);
		
		foreach($node->attributes as $attr) {
			if($attr->name == 'color' || $attr->name == 'style' || $attr->name == 'src') {
				$saveto->setAttributeNode($saveto->ownerDocument->importNode($attr, TRUE));
			}
		}
		
		return $saveto;
	}
	
	static function insertElement($tag, $node) {
		$tag = $node->ownerDocument->createElement($tag);
		$tag->setAttribute('auto', '1');
		$node->appendChild($tag);
	}
}
?>

==> bot_2.3.tar.bz2: bot/class/DOMHelper.php <==
<?php
/************************************************** 
 *                 Bot Gadu-Gadu                  * 
 ************************************************** 
 * Wersja: 2.3 Stable                             * 
 * Data: 13.07.2012 (21:01)                       * 
 * Autor: Jacek Kowalski (http://jacekk.info)     * 
 *                                                * 
 * Utwor rozprowadzany na licencji                * 
 * http://creativecommons.org/licenses/by-nc/2.5/ * 
 **************************************************/

class DOMHelper {
	static function ltrim($node) {
		while(($node->firstChild instanceof DOMElement) && $node->firstChild->tagName == 'br' && $node->firstChild->getAttribute('auto')=='1') {
			$node->removeChild($node->firstChild);
		}
		
		if($node->firstChild instanceof DOMElement) {
			self::ltrim($node->firstChid);
		}
	}
	
	static function rtrim($node) {
		while(($node->lastChild instanceof DOMElement) && $node->lastChild->tagName == 'br' && $node->lastChild->getAttribute('auto')=='1') {
			$node->removeChild($node->lastChild);
		}
		
		if($node->lastChild instanceof DOMElement) {
			self::rtrim($node->lastChild);
		}
	}
	
	static function trim($node) {
		self::ltrim($node);
		self::rtrim($node);
	}
	
	static function cloneNode($node, $saveto, $tag=NULL) {
		if($tag === NULL) {
			$tag = $node->tagName;
		}
		
		$saveto = $saveto->ownerDocument->createElement($tag);
		
		foreach($node->attributes as $attr) {
			if($attr->name == 'color' || $attr->name == 'style' || $attr->name == 'src') {
				$saveto->setAttributeNode($saveto->ownerDocument->importNode($attr, TRUE));
			}
		}
		
		return $saveto;
	}
	
	static function insertElement($tag, $node) {
		$tag = $node->ownerDocument->createElement($tag);
		$tag->setAttribute('auto', '1');
		$node->appendChild($tag);
	}
}
?>
